/**
 * Copyright (c) 2022 - present TinyVue Authors.
 * Copyright (c) 2022 - present Huawei Cloud Computing Technologies Co., Ltd.
 *
 * Use of this source code is governed by an MIT-style license.
 *
 * THE OPEN SOURCE SOFTWARE IN THIS PRODUCT IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,
 * BUT WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS FOR
 * A PARTICULAR PURPOSE. SEE THE APPLICABLE LICENSES FOR MORE DETAILS.
 *
 */
/** 绑定事件 */
export declare const on: (el: EventTarget, event: any, handler: (this: HTMLElement, ev: any) => any, options?: boolean) => void;
/** 移除事件 */
export declare const off: (el: EventTarget, event: any, handler: (this: HTMLElement, ev: any) => any, options?: boolean) => void;
/** 执行一次就立即移除事件 */
export declare const once: (el: HTMLElement, event: any, fn: (this: HTMLElement, ev: any) => any) => void;
/** 判断是否有class,  只能查询单个类名， 且不能有空格 */
export declare const hasClass: (el: HTMLElement, clazz: string) => boolean | undefined;
/** 给el添加一组classes,  clazz 允许为用空格分隔的多个类名  */
export declare const addClass: (el: HTMLElement, clazz?: string) => void;
/** 移除el上的classes， clazz 允许为用空格分隔的多个类名  */
export declare const removeClass: (el: HTMLElement, clazz: string) => void;
/** 查询元素的style的值。 优先找el.style, 找不到则调用getComputedStyle(el)  */
export declare const getStyle: (el: HTMLElement, styleName: string) => any;
/** 给元素赋值style。
 * @param name  当它是对象时，遍历所有属性；当它是字符串时，需要传入第3个参数 value
 */
export declare const setStyle: (el: HTMLElement, name: string | object, value?: any) => void;
/** 判断元素是否有滚动的style TINY_NO_USED
 * @param vertical  true时，只判断overflow-y属性；  false时，只判断overflow-x属性；  不传入时，只判断overflow属性！
 */
export declare const isScroll: (el: HTMLElement, vertical?: boolean) => any;
/** 查找离元素最近的父级滚动元素
 * @param vertical  true时，只判断overflow-y属性；  false时，只判断overflow-x属性；  不传入时，只判断overflow属性！
 */
export declare const getScrollContainer: (el: HTMLElement, vertical?: boolean) => (Window & typeof globalThis) | HTMLElement | undefined;
/** 判断是否 el 完全在  container 中。  四个边有重合都不行，必须完全在里面。 */
export declare const isInContainer: (el: HTMLElement, container: HTMLElement) => boolean;
/** 查询页面的位置和尺寸
 * @returns scrollTop ： document 或 body的滚动位置
 * @returns scrollLeft ： document 或 body的滚动位置
 * @returns visibleHeight ： 可视区高度 （不含滚动条）
 * @returns visibleWidth ： 可视区宽度（不含滚动条）
 */
export declare const getDomNode: () => {
    scrollTop: number;
    scrollLeft: number;
    visibleHeight: number;
    visibleWidth: number;
};
export declare const getScrollTop: (el: any) => number;
export declare const stopPropagation: (event: any) => any;
export declare const preventDefault: (event: any, isStopPropagation: any) => void;
export declare const getScrollParent: (el: any, root?: (Window & typeof globalThis) | undefined) => any;
export declare const useScrollParent: ({ onMounted, ref, watch }: {
    onMounted: any;
    ref: any;
    watch: any;
}) => (elRef: any, root?: (Window & typeof globalThis) | undefined) => any;
export declare const isDisplayNone: (elm: any) => any;
